package pl.koziolekweb.programmers.zip;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.util.zip.Adler32;
import java.util.zip.CheckedOutputStream;
import java.util.zip.ZipOutputStream;

/**
 * 
 * Klasa tworzy archiwum za pomocą algorytmu ZIP.
 * 
 * @author koziolek
 * 
 */
final class ArchiverChecksumZIPImpl extends AchiverAbstractZIPImpl {

	private CheckedOutputStream checksumStream;

	/**
	 * Używany jest domyślny poziom kompresji (5)
	 */
	ArchiverChecksumZIPImpl() {
		this(LEVEL._5);
	}

	/**
	 * Używany jest wskazany poziom kompresji.
	 * 
	 * @param compresionLevel
	 *            poziom kompresji.
	 */
	ArchiverChecksumZIPImpl(LEVEL compresionLevel) {
		this.compresionLevel = compresionLevel;
	}

	/**
	 * Metoda ustawia pośredni strumien klasy {@link CheckedOutputStream}.
	 * 
	 * @param target
	 *            plik wynikowy.
	 * @throws FileNotFoundException
	 *             jeżeli nie można znaleźć pliku wynikowego
	 */
	protected void makeStreams(File target) throws FileNotFoundException {
		dest = new FileOutputStream(target);
		checksumStream = new CheckedOutputStream(dest, new Adler32());
		out = new ZipOutputStream(new BufferedOutputStream(checksumStream));
		out.setLevel(compresionLevel.lvl);
	}

}