package pl.koziolekweb.programmers.zip;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * 
 * Klasa tworzy archiwum za pomocą algorytmu ZIP.
 * 
 * @author koziolek
 * 
 */
public class ArchiverImpl implements Archiver {
	private static final int BUFFER = 2048;
	private FileOutputStream dest;
	private ZipOutputStream out;
	private BufferedInputStream origin;
	private String basePath;
	private LEVEL compresionLevel;

	/**
	 * Uzywany jest domyślny poziom kompresji (5)
	 */
	public ArchiverImpl() {
		this.compresionLevel = LEVEL._5;
	}

	/**
	 * Używany jest wskazany poziom kompresji.
	 * 
	 * @param compresionLevel
	 *            poziom kompresji.
	 */
	public ArchiverImpl(LEVEL compresionLevel) {
		this.compresionLevel = compresionLevel;
	}

	/**
	 * Poziom kompresji.
	 * 
	 * @author koziolek
	 * 
	 */
	public enum LEVEL {
		_0(0), _1(1), _2(2), _3(3), _4(4), _5(5), _6(6), _7(7), _8(8), _9(9);

		private LEVEL(int lvl) {
			this.lvl = lvl;
		}

		int lvl;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see pl.koziolekweb.programmers.zip.Archiver#archive(File, File)
	 */
	@Override
	public void archive(File source, File target) throws IOException {
		if (!target.exists()) {
			target.createNewFile();
		}
		dest = new FileOutputStream(target);
		out = new ZipOutputStream(new BufferedOutputStream(dest));
		out.setLevel(compresionLevel.lvl);
		basePath = source.getAbsolutePath();
		if (source.isDirectory()) {
			archiveDir(source);
		} else {
			archiveFile(source);
		}
		out.close();
	}

	/**
	 * Przetwarza rekurencyjnie folder jeżeli próbujemy dodać go do archiwum.
	 * Jeżeli przekażemy do metody zwykły plik to zostanie on zignorowany.
	 * 
	 * @param file
	 *            folder.
	 * @throws IOException
	 */
	private void archiveDir(File file) throws IOException {
		if (file.isFile()) {
			System.out.println("Ignoruję zwykły plik: "
					+ file.getAbsolutePath());
		}
		for (File f : file.listFiles()) {
			if (f.isDirectory()) {
				archiveDir(f);
			} else {
				archiveFile(f);
			}
		}
	}

	/**
	 * Dodaje wskazany plik do archiwum.
	 * 
	 * @param file
	 *            plik do dodania.
	 * @throws IOException
	 */
	private void archiveFile(File file) throws IOException {
		String targetFilePath = file.getAbsolutePath().replace(basePath, "");
		System.out.println("Pakuję plik " + targetFilePath);
		byte data[] = new byte[BUFFER];
		FileInputStream fi = new FileInputStream(file);
		origin = new BufferedInputStream(fi, BUFFER);
		ZipEntry entry = new ZipEntry(targetFilePath);
		out.putNextEntry(entry);
		int count;
		while ((count = origin.read(data, 0, BUFFER)) != -1) {
			out.write(data, 0, count);
		}
		origin.close();
	}
}
