package pl.koziolekweb.programmers.zip;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.util.zip.ZipOutputStream;

/**
 * 
 * Klasa tworzy archiwum za pomocą algorytmu ZIP.
 * 
 * @author koziolek
 * 
 */
final class ArchiverSimpleZIPImpl extends AchiverAbstractZIPImpl {

	/**
	 * Używany jest domyślny poziom kompresji (5)
	 */
	ArchiverSimpleZIPImpl() {
		this(LEVEL._5);
	}

	/**
	 * Używany jest wskazany poziom kompresji.
	 * 
	 * @param compresionLevel
	 *            poziom kompresji.
	 */
	ArchiverSimpleZIPImpl(LEVEL compresionLevel) {
		this.compresionLevel = compresionLevel;
	}

	/**
	 * Konfiguruje strumienie. Nie tworzy pośrednikow.
	 * 
	 * @param target
	 *            plik archiwum.
	 * @throws FileNotFoundException
	 *             jeżeli nie istnieje plik wynikowy.
	 */
	@Override
	protected void makeStreams(File target) throws FileNotFoundException {
		dest = new FileOutputStream(target);
		out = new ZipOutputStream(new BufferedOutputStream(dest));
		out.setLevel(compresionLevel.lvl);
	}

}