package pl.koziolekweb.programmers.zip;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;

/**
 * Klasa rozpakowuje pliki ZIP.
 * 
 * @author koziolek
 * 
 */
public final class UnarchiverZip implements Unarchiver {

	private static final int BUFFER = 2048;

	@Override
	public void unarchive(File source, File target) throws IOException {
		BufferedOutputStream dest = new BufferedOutputStream(
				new FileOutputStream(target));
		FileInputStream fis = new FileInputStream(source);
		ZipInputStream zis = new ZipInputStream(new BufferedInputStream(fis));
		ZipEntry entry;
		while ((entry = zis.getNextEntry()) != null) {
			int count;
			byte data[] = new byte[BUFFER];
			if (entry.isDirectory()) {
				File f = new File(target.getAbsolutePath() + entry.getName());
				if (!f.exists()) {
					f.mkdirs();
				}
				continue;
			}
			FileOutputStream fos = new FileOutputStream(entry.getName());
			dest = new BufferedOutputStream(fos, BUFFER);
			while ((count = zis.read(data, 0, BUFFER)) != -1) {
				dest.write(data, 0, count);
			}
			dest.flush();
			dest.close();
		}
		zis.close();
	}
}